@@ -1,3 +1,5 @@
+from .version import __version__
+
 from .core import *
 
 def split_size_2d(s):
@@ -14,3 +16,7 @@ def split_size_2d(s):
             break
         a = a - 1 
     return a, d
+
+from numpy.testing import Tester
+test = Tester().test
+bench = Tester().bench
